@@ -23,6 +23,6 @@ export RUSTC_BOOTSTRAP="1"   # hack to make -Zprofile work on the non-nightly co
 export CARGO_INCREMENTAL="0" # -Zprofile (gcov) doesn't like incremental compilation
 export RUSTFLAGS="-Zprofile -Ccodegen-units=1 -Clink-dead-code -Coverflow-checks=off"
 
-meson setup _build -Db_coverage=true -Dauto_features=disabled -Dpixbuf{,-loader}=enabled -Dtests=enabled --buildtype=debugoptimized
+meson setup _build -Db_coverage=true -Dauto_features=disabled -Dpixbuf{,-loader}=enabled --buildtype=debugoptimized
 meson compile -C _build
 meson test -C _build --maxfail 0 --print-errorlogs
